==> Biostrings_2.8.18.zip: Biostrings/doc/Biostrings2Classes.R <==
###################################################
### chunk number 1: a1
###################################################
library(Biostrings)
b <- BString("I am a BString object")
b
length(b)


###################################################
### chunk number 2: a2
###################################################
d <- DNAString("TTGAAAA-CTC-N")
d
length(d)


###################################################
### chunk number 3: a3
###################################################
d[3]
d[7:12]
d[]
b[length(b):1]


###################################################
### chunk number 4: a4
###################################################
bb <- subXString(b, 3, 6)
dd1 <- subXString(d, end=7)
dd2 <- subXString(d, start=8)


###################################################
### chunk number 5: a5
###################################################
toString(dd2)


###################################################
### chunk number 6: b1
###################################################
bb == "am a"
dd2 != DNAString("TG")


###################################################
### chunk number 7: b2
###################################################
cat('> bb == ""')
cat('> d == bb')


###################################################
### chunk number 8: b3
###################################################
r <- RNAString(d)
r
r == d


###################################################
### chunk number 9: c1
###################################################
v4 <- views(dd2, 3:0, 5:8)
v4
length(v4)


###################################################
### chunk number 10: c3
###################################################
v4[4:2]


###################################################
### chunk number 11: c4
###################################################
v4[[2]]


###################################################
### chunk number 12: c6
###################################################
cat('> v4[[3]]')
cat(try(v4[[3]], silent=TRUE))


###################################################
### chunk number 13: c7
###################################################
v4[[0]]


###################################################
### chunk number 14: c8
###################################################
v4[-3]
v4[c(TRUE, FALSE)]


###################################################
### chunk number 15: d1
###################################################
v12 <- views(DNAString("TAATAATG"), -2:9, 0:11)


###################################################
### chunk number 16: d2
###################################################
views(d)


###################################################
### chunk number 17: d3
###################################################
views(d)[[1]]


###################################################
### chunk number 18: d4
###################################################
v12[0]
v12[FALSE]
views(d, integer(0), integer(0))


###################################################
### chunk number 19: e1
###################################################
v12 == DNAString("TAA")


###################################################
### chunk number 20: e2
###################################################
v12[v12 == v12[4]]
v12[v12 == v12[1]]


###################################################
### chunk number 21: e2
###################################################
v12[3] == views(RNAString("AU"), 0, 2)


###################################################
### chunk number 22: f1
###################################################
start(v4)
end(v4)
width(v4)

==> Biostrings_2.10.22.zip: Biostrings/doc/Biostrings2Classes.R <==
###################################################
### chunk number 1: a1
###################################################
library(Biostrings)
b <- BString("I am a BString object")
b
length(b)


###################################################
### chunk number 2: a2
###################################################
d <- DNAString("TTGAAAA-CTC-N")
d
length(d)


###################################################
### chunk number 3: a3
###################################################
d[3]
d[7:12]
d[]
b[length(b):1]


###################################################
### chunk number 4: a4
###################################################
bb <- subXString(b, 3, 6)
dd1 <- subXString(d, end=7)
dd2 <- subXString(d, start=8)


###################################################
### chunk number 5: a5
###################################################
toString(dd2)


###################################################
### chunk number 6: b1
###################################################
bb == "am a"
dd2 != DNAString("TG")


###################################################
### chunk number 7: b2
###################################################
cat('> bb == ""')
cat('> d == bb')


###################################################
### chunk number 8: b3
###################################################
r <- RNAString(d)
r
r == d


###################################################
### chunk number 9: c1
###################################################
v4 <- Views(dd2, start=3:0, end=5:8)
v4
length(v4)


###################################################
### chunk number 10: c3
###################################################
v4[4:2]


###################################################
### chunk number 11: c4
###################################################
v4[[2]]


###################################################
### chunk number 12: c6
###################################################
cat('> v4[[3]]')
cat(try(v4[[3]], silent=TRUE))


###################################################
### chunk number 13: c7
###################################################
v4[-3]
v4[c(TRUE, FALSE)]


###################################################
### chunk number 14: d1
###################################################
v12 <- Views(DNAString("TAATAATG"), start=-2:9, end=0:11)


###################################################
### chunk number 15: d2
###################################################
Views(d)


###################################################
### chunk number 16: d3
###################################################
Views(d)[[1]]


###################################################
### chunk number 17: d4
###################################################
v12[0]
v12[FALSE]
Views(d, start=integer(0), end=integer(0))


###################################################
### chunk number 18: e1
###################################################
v12 == DNAString("TAA")


###################################################
### chunk number 19: e2
###################################################
v12[v12 == v12[4]]
v12[v12 == v12[1]]


###################################################
### chunk number 20: e2
###################################################
v12[3] == Views(RNAString("AU"), start=0, end=2)


###################################################
### chunk number 21: f1
###################################################
start(v4)
end(v4)
width(v4)
